//
//  GMTDAuthorization.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTDAuthorizationContext.h"

NS_ASSUME_NONNULL_BEGIN

/**
 * \defgroup GMTDAuthTokenFetchCompletionHandler GMTDAuthTokenFetchCompletionHandler
 * @{
 */

/**
 * Completion handler called when an authorization token is available.
 *
 * @param authToken The authorization token. If an error occurs, this parameter is null.
 * @param error The error that occurs if any.
 */
typedef void (^GMTDAuthTokenFetchCompletionHandler)(NSString *_Nullable authToken,
                                                    NSError *_Nullable error);

/**@}*/

/**
 * Protocol used to provide authorization tokens for gRPC calls. These tokens
 * give access to the Fleet Engine service accounts.
 *
 * The implementation should ensure that a valid authorization token is always available.
 * The authorization token should have a minimum lifetime of 5 minutes to allow for requests to
 * complete. Therefore, the authorization token must automatically renew expiring tokens and
 * minimize the number of token refreshes by re-using a token until its lifetime nears its end.
 *
 * Implementations of this protocol must be thread-safe.
 */
@protocol GMTDAuthorization <NSObject>

/**
 * Called by the SDK to fetch a JWT. The implementation must assume that this method
 * may be invoked from arbitrary queues.
 *
 * @param authorizationContext The context of the target authorization token.
 * @param completion Must be called asynchronously, but can be called from any queue.
 */
- (void)fetchTokenWithContext:(nullable GMTDAuthorizationContext *)authorizationContext
                   completion:(GMTDAuthTokenFetchCompletionHandler)completion;

@end

NS_ASSUME_NONNULL_END
