//
//  GMTDCreateDeliveryTaskRequest.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>


#import "GMTDDeprecationMacros.h"
#import "GMTSTask.h"
#import "GMTSFleetEngineIDString.h"

@class GMSNavigationWaypoint;

NS_ASSUME_NONNULL_BEGIN

/** An immutable object representing a request to create a delivery task. */
@interface GMTDCreateDeliveryTaskRequest : GMTSImmutableData

/** Use @c initWithTaskID:trackingID:taskType:taskState:taskDuration:plannedWaypoint: instead. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

/** The ID of the task. */
@property(nonatomic, readonly) GMTSFleetEngineIDString *taskID;

/** The tracking ID for the task. */
@property(nonatomic, readonly, nullable) GMTSFleetEngineIDString *trackingID;

/** The tracking ID for the task. */
@property(nonatomic, readonly, nullable) NSString *parentID __GMTD_AVAILABLE_BUT_DEPRECATED_MSG(
    "This property is obsolete and will be removed in a future "
    "release. Use the trackingID property instead.");

/** The type of the task. */
@property(nonatomic, readonly) GMTSTaskType taskType;

/** The state of the task. */
@property(nonatomic, readonly) GMTSTaskState taskState;

/** The expected duration of the task in seconds. */
@property(nonatomic, readonly) NSTimeInterval taskDuration;

/** Optional waypoint where the task will be performed. */
@property(nonatomic, readonly, nullable) GMSNavigationWaypoint *plannedWaypoint;


/**
 * Initializes and returns a @c GMTDCreateDeliveryTaskRequest object using the provided attributes.
 *
 * @param taskID The ID of the task.
 * @param trackingID An abitrary ID the client may find useful in tracking the task.
 * @param taskType The type of this task.
 * @param taskState The state of this task.
 * @param taskDuration The expected duration of this task in seconds.
 * @param plannedWaypoint The location where this task will be performed.
 */
- (instancetype)initWithTaskID:(GMTSFleetEngineIDString *)taskID
                    trackingID:(nullable GMTSFleetEngineIDString *)trackingID
                      taskType:(GMTSTaskType)taskType
                     taskState:(GMTSTaskState)taskState
                  taskDuration:(NSTimeInterval)taskDuration
               plannedWaypoint:(nullable GMSNavigationWaypoint *)plannedWaypoint
    NS_DESIGNATED_INITIALIZER;


@end

NS_ASSUME_NONNULL_END
