//
//  GMTDDeliveryDriverAPI.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTDDriverAPI.h"

@class GMTDDeliveryTaskManager;
@class GMTDDeliveryVehicleManager;
@class GMTDDeliveryVehicleReporter;

NS_ASSUME_NONNULL_BEGIN

/**
 * A class that provides access to all the core components and serves as the entry
 * point for the Delivery vertical.
 */
@interface GMTDDeliveryDriverAPI : GMTDDriverAPI

/** The vehicle reporter used to send updates to the Fleet Engine backend. */
@property(nonatomic, readonly) GMTDDeliveryVehicleReporter *vehicleReporter;

/** The task manager used to create or update delivery tasks. */
@property(nonatomic, readonly, nullable) GMTDDeliveryTaskManager *deliveryTaskManager;

/** The vehicle manager used to create or get delivery vehicles. */
@property(nonatomic, readonly, nullable) GMTDDeliveryVehicleManager *deliveryVehicleManager;

/**
 * Initializes the API.
 *
 * After initialization, driver APIs from different verticals should not be used
 * until this instance has been deallocated.
 * Using driver API instances from multiple verticals in the same SDK session
 * can lead to unexpected behavior.
 *
 * @param driverContext An object containing the necessary information for initialization.
 *
 * @return An instance of the API.
 */
- (nullable instancetype)initWithDriverContext:(GMTDDriverContext *)driverContext;

/** Use @c initWithDriverContext: instead. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
