//
//  GMTDDeliveryTaskManager.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

@class GMTDCreateDeliveryTaskRequest;
@class GMTDDeliveryTask;
@class GMTDServices;
@class GMTDUpdateDeliveryTaskRequest;

NS_ASSUME_NONNULL_BEGIN

/**
 * \defgroup GMTDDeliveryTaskManagerCompletionHandler GMTDDeliveryTaskManagerCompletionHandler
 * @{
 */

/**
 * Completion handler type definition for the create and update task operations.
 *
 * @param task The created or updated delivery task. If the requests fails, is null.
 * @param error The error that occurs. If the request succeeds, is null.
 */
typedef void (^GMTDDeliveryTaskManagerCompletionHandler)(GMTDDeliveryTask *_Nullable task,
                                                         NSError *_Nullable error);

/**@}*/

/** Object that manages task creation and updates. */
@interface GMTDDeliveryTaskManager : NSObject

/**
 * This class has no public initializers; obtain this object from the @c deliveryTaskManager
 * property of the @c GMTDDeliveryDriverAPI object.
 */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

/**
 * Updates a task with the given request.
 *
 * @param request The request to update the task.
 * @param completion A block to be executed when the request is completed.
 */
- (void)updateTaskWithRequest:(GMTDUpdateDeliveryTaskRequest *)request
                   completion:(GMTDDeliveryTaskManagerCompletionHandler)completion;

/**
 * Creates a task with the given request.
 *
 * @param request The request to create the task.
 * @param completion A block to be executed when the request is completed.
 */
- (void)createTaskWithRequest:(GMTDCreateDeliveryTaskRequest *)request
                   completion:(GMTDDeliveryTaskManagerCompletionHandler)completion;
@end

NS_ASSUME_NONNULL_END
