//
//  GMTDDeliveryVehicleManager.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

@class GMTDDeliveryVehicle;

NS_ASSUME_NONNULL_BEGIN

/** Class used to create and retrieve delivery vehicles from Fleet Engine */
@interface GMTDDeliveryVehicleManager : NSObject

/**
 * \defgroup GMTDDeliveryVehicleManagerCompletionHandler GMTDDeliveryVehicleManagerCompletionHandler
 * @{
 */

/**
 * Completion handler type definition for the create and get vehicle operations.
 *
 * @param vehicle The created or retrieved delivery vehicle. If request fails, is null.
 * @param error The error that occurs. If request succeeds, is null.
 */
typedef void (^GMTDDeliveryVehicleManagerCompletionHandler)(GMTDDeliveryVehicle *_Nullable vehicle,
                                                            NSError *_Nullable error);

/**@}*/

/** This class may only be initialized internally. */
- (instancetype)init NS_UNAVAILABLE;

/**
 * Creates a vehicle on Fleet Engine.
 *
 * @param completion The block executed when a response from Fleet Engine is received.
 */
- (void)createVehicleWithCompletion:(GMTDDeliveryVehicleManagerCompletionHandler)completion;

/**
 * Retrieves a vehicle from Fleet Engine.
 *
 * @param completion The block executed when a response from Fleet Engine is received.
 */
- (void)getVehicleWithCompletion:(GMTDDeliveryVehicleManagerCompletionHandler)completion;
@end

NS_ASSUME_NONNULL_END
