//
//  GMTDDriverAPI.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

@class GMTDDriverContext;

NS_ASSUME_NONNULL_BEGIN

/** An abstract superclass for the Driver SDK API classes. */
@interface GMTDDriverAPI : NSObject <NSCopying>

/**
 * Returns the version for this release of the Google On Demand Rides and Deliveries Driver SDK for
 * iOS. For example, "0.4.4". The version is in the SDK's resource bundle.
 */
+ (NSString *)SDKVersion;

/**
 * Returns the long formatted version string. It includes the version
 * string and bundle version in format "<SHORT VERSION> (<BUNDLE VERSION>)".
 * For example, "0.4.4 (234.2)".
 */
+ (NSString *)SDKLongVersion;

/**
 * Enables reporting of abnormal SDK terminations such as when the app crashes while the SDK is
 * still running. This allows Google to improve SDK stability when applicable. The default is @c YES
 * and value must be updated before the `initWithDriverContext` is called.
 *
 * This property must be set from the main thread.
 */
+ (void)setAbnormalTerminationReportingEnabled:(BOOL)abnormalTerminationReportingEnabled;

/** This abstract superclass cannot be directly instantiated. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
