//
//  GMTDDriverContext.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTSFleetEngineIDString.h"
#import "GMTSImmutableData.h"

@class GMSNavigator;
@protocol GMTDAuthorization;

NS_ASSUME_NONNULL_BEGIN

/** An object containing the dependencies needed to construct a @c GMTDDriverApi instance. */
@interface GMTDDriverContext : GMTSImmutableData

/** Object that provides access tokens for interacting with the Fleet Engine backend. */
@property(nonatomic, readonly) id<GMTDAuthorization> accessTokenProvider;

/** The ID for the Google Cloud project associated with the provider. */
@property(nonatomic, readonly, copy) NSString *providerID;

/** The ID associated with the vehicle. */
@property(nonatomic, readonly, copy) GMTSFleetEngineIDString *vehicleID;

/** The navigator associated with the @c GMSMapView. Used to track navigation-related changes. */
@property(nonatomic, readonly) GMSNavigator *navigator;

/**
 * Initializes the Driver Context object.
 *
 * @param accessTokenProvider  Object that provides access tokens for interacting with the Fleet
 * Engine backend.
 * @param providerID The ID for the Google Cloud project associated with the provider.
 * @param vehicleID The ID associated with the vehicle.
 * @param navigator The navigator associated with the @c GMSMapView. Used to track
 * navigation-related changes.
 *
 * @return An instance of the Driver Context.
 */
- (instancetype)initWithAccessTokenProvider:(id<GMTDAuthorization>)accessTokenProvider
                                 providerID:(NSString *)providerID
                                  vehicleID:(GMTSFleetEngineIDString *)vehicleID
                                  navigator:(GMSNavigator *)navigator;

/** Use @c initWithAccessTokenProvider:providerID:vehicleID:navigator: instead. */
- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
