//
//  GMTDRidesharingDriverAPI.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//
#import <Foundation/Foundation.h>

#import "GMTDDriverAPI.h"

@class GMTDVehicleReporter;

NS_ASSUME_NONNULL_BEGIN

/**
 * A class that provide access to all the core components and serves as the entry point for the
 * ridesharing use case.
 */
@interface GMTDRidesharingDriverAPI : GMTDDriverAPI

/** The vehicle reporter used to send updates to the Fleet Engine backend. */
@property(nonatomic, readonly) GMTDVehicleReporter *vehicleReporter;

/**
 * Initializes the API.
 *
 * After initialization, driver APIs from different verticals should not be used until this instance
 * has been deallocated. Using driver API instances from multiple verticals in the same SDK session
 * can lead to unexpected behavior.
 *
 * @param driverContext An object containing the necessary information for initialization.
 *
 * @return An instance of the API.
 */
- (nullable instancetype)initWithDriverContext:(GMTDDriverContext *)driverContext;

/** Use @c initWithDriverContext: instead. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
