//
//  GMTDUpdateDeliveryTaskRequest.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTSTask.h"
#import "GMTSFleetEngineIDString.h"
#import "GMTSImmutableData.h"

NS_ASSUME_NONNULL_BEGIN

/** An immutable object representing a request to update a delivery task. */
@interface GMTDUpdateDeliveryTaskRequest : GMTSImmutableData

/**
 * Initializes and returns a @c GMTDCreateDeliveryTaskRequest object using the provided attributes.
 *
 * @param taskID The ID of the task.
 * @param taskOutcome The outcome of the task.
 * @param outcomeTimestamp The time when the outcome was reported.
 */
- (instancetype)initWithTaskID:(GMTSFleetEngineIDString *)taskID
                   taskOutcome:(GMTSTaskOutcome)taskOutcome
          taskOutcomeTimestamp:(NSTimeInterval)outcomeTimestamp NS_DESIGNATED_INITIALIZER;

/** Use @c initWithTaskID:taskOutcome:taskOutcomeTimestamp: instead. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

/** The ID of the task. */
@property(nonatomic, readonly) GMTSFleetEngineIDString *taskID;

/** The outcome of the task. */
@property(nonatomic, readonly) GMTSTaskOutcome taskOutcome;

/** The time the outcome occurred. */
@property(nonatomic, readonly) NSTimeInterval outcomeTimestamp;

@end

NS_ASSUME_NONNULL_END
