//
//  GMTDVehicleStop.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTDDeprecationMacros.h"
#import "GMTSImmutableData.h"

@class GMSNavigationWaypoint;
@class GMTSTaskInfo;

NS_ASSUME_NONNULL_BEGIN

/** An object representing a vehicle stop for deliveries. */
@interface GMTDVehicleStop : GMTSImmutableData

/**
 * \defgroup GMTDVehicleStopState GMTDVehicleStopState
 * @{
 */

/** Enum representing all possible VehicleStop states. */
typedef NS_ENUM(NSUInteger, GMTDVehicleStopState) {
  GMTDVehicleStopStateUnspecified = 0,
  GMTDVehicleStopStateNew,
  GMTDVehicleStopStateEnroute,
  GMTDVehicleStopStateArrived,
};

/**@}*/

/** The array of TaskInfo objects to be performed at this stop. */
@property(nonatomic, readonly, copy) NSArray<GMTSTaskInfo *> *taskInfoArray;

/** The waypoint for the stop. */
@property(nonatomic, readonly, nullable) GMSNavigationWaypoint *plannedWaypoint;

/** The current state of a VehicleStop. */
@property(nonatomic, readonly) GMTDVehicleStopState state;

/**
 * Instantiates an instance of this class.
 *
 * @param taskInfoArray  The list of tasks to be performed at this stop.
 * @param plannedWaypoint The waypoint of the stop.
 * @param state The state of the VehicleStop.
 */
- (instancetype)initWithTaskInfoArray:(NSArray<GMTSTaskInfo *> *)taskInfoArray
                      plannedWaypoint:(nullable GMSNavigationWaypoint *)plannedWaypoint
                                state:(GMTDVehicleStopState)state NS_DESIGNATED_INITIALIZER;

/** Use @c initWithTaskInfoArray:plannedWaypoint:state: instead. */
- (instancetype)init NS_UNAVAILABLE;
@end

NS_ASSUME_NONNULL_END
