//
//  GMTDVehicleUpdate.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTDFleetEngineEnums.h"

@class CLLocation;
@class GMSNavigationWaypoint;

NS_ASSUME_NONNULL_BEGIN

/** Object representing a vehicle update. */
@interface GMTDVehicleUpdate : NSObject <NSCopying>

/** The vehicle state. */
@property(nonatomic, readonly) GMTDVehicleState vehicleState;

/** The location. */
@property(nonatomic, readonly, copy, nullable) CLLocation *location;

/** The destination waypoint. */
@property(nonatomic, readonly, nullable) GMSNavigationWaypoint *destinationWaypoint;

/** The route to the destination. */
@property(nonatomic, readonly, copy, nullable) NSArray<CLLocation *> *route;

/** The remaining time to the destination, in seconds. */
@property(nonatomic, readonly, copy, nullable) NSNumber *remainingTimeInSeconds;

/** The remaining distance in meters to the destination. */
@property(nonatomic, readonly, copy, nullable) NSNumber *remainingDistanceInMeters;

/** This object is initialized by the @c GMTDVehicleReporter and not intended by developers. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
