//
//  GMTSTaskInfo.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//
#import <Foundation/Foundation.h>

#import "GMTSFleetEngineIDString.h"
#import "GMTSImmutableData.h"

NS_ASSUME_NONNULL_BEGIN

/**
 * An immutable object representing a task that will be completed at a vehicle stop.
 */
@interface GMTSTaskInfo : GMTSImmutableData

/** The unique ID of the task. */
@property(nonatomic, readonly, copy) GMTSFleetEngineIDString *taskID;

/** The time required to perform the task. */
@property(nonatomic, readonly) NSTimeInterval taskDuration;

/**
 * Instantiates an instance of this class.
 *
 * @param taskID  The ID of a task.
 * @param taskDuration The time required to perform the task.
 */
- (instancetype)initWithTaskID:(GMTSFleetEngineIDString *)taskID
                  taskDuration:(NSTimeInterval)taskDuration;

/**
 * Use @c nitWithTaskID:taskDuration: instead.
 */
- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
