//
//  GMTSTimestamp.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSImmutableData.h"

/**
 * Object representing a timestamp.
 */
@interface GMTSTimestamp : GMTSImmutableData

/**
 * Represents seconds of UTC time since Unix epoch
 * 1970-01-01T00:00:00Z. Must be from 0001-01-01T00:00:00Z to
 * 9999-12-31T23:59:59Z inclusive.
 **/
@property(nonatomic, readonly) int64_t seconds;

/**
 * Non-negative fractions of a second at nanosecond resolution. Negative
 * second values with fractions must still have non-negative nanos values
 * that count forward in time. Must be from 0 to 999,999,999
 * inclusive.
 **/
@property(nonatomic, readonly) int32_t nanos;

/**
 * Instantiates the object with the specified `seconds` and `nanos'.
 */
- (instancetype)initWithSeconds:(int64_t)seconds nanos:(int32_t)nanos;

/**
 * Use @c initWithSeconds:nanos: instead.
 */
- (instancetype)init NS_UNAVAILABLE;

@end
