//
//  GMTSVehicleMatch.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSImmutableData.h"

@class GMTSTimestamp;
@class GMTSVehicle;
@class GPBInt32Value;

enum GMTSTripType : NSUInteger;

NS_ASSUME_NONNULL_BEGIN

/**
 * Object that contains the vehicle's information, ETA, and distance
 * calculations for a vehicle that matches the SearchVehiclesRequest.
 */
@interface GMTSVehicleMatch : GMTSImmutableData

/**
 * The related vehicle information.
 */
@property(nonatomic, readonly, copy, nullable) GMTSVehicle *vehicle;

/**
 * The timestamp of the pickup ETA.
 */
@property(nonatomic, readonly) NSTimeInterval pickupETA;

/**
 * The distance from current location to the pickup location.
 */
@property(nonatomic, readonly) int32_t pickupDistanceInMeters;

/**
 * The timestamp of the drop off ETA.
 */
@property(nonatomic, readonly) NSTimeInterval dropoffETA;

/**
 * The distance from pickup to drop off.
 */
@property(nonatomic, readonly) int32_t pickupToDropoffDistanceInMeters;

/**
 * The trip type of the vehicle.
 */
@property(nonatomic, readonly) enum GMTSTripType tripType;

/**
 * Initialization of the object.
 *
 * @param vehicle  The vehicle data.
 * @param pickupETA  The timestamp of the pickup ETA.
 * @param pickupDistance  The distance from current location to the pickup point.
 * @param dropoffETA  The timestamp of the drop off ETA.
 * @param pickupToDropoffDistance  The distance from pickup to drop off.
 * @param tripType  The trip type.
 */
- (instancetype)initWithVehicle:(nullable GMTSVehicle *)vehicle
                      pickupETA:(NSTimeInterval)pickupETA
                 pickupDistance:(int32_t)pickupDistance
                     dropoffETA:(NSTimeInterval)dropoffETA
        pickupToDropoffDistance:(int32_t)pickupToDropoffDistance
                       tripType:(enum GMTSTripType)tripType
    __deprecated_msg("GMTSVehicleMatch is deprecated.");

/**
 * Use @c initWithVehicle:vehiclePickupETA:vehicleDropoffETA:vehiclePickupToDropoffDistance:
 * tripType: instead.
 */
- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
